import uuid

import click

from gcs_cli.helpers import requires_login
from gcs_cli.parsing import globus_command
from gcs_cli.sdk_client.auth_client import MissingConsent
from gcs_cli.services.auth import get_client


@globus_command(
    "delete",
    short_help="Delete a GCS endpoint client.",
    disable_options=["explicit_host"],
)
@click.argument("CLIENT_ID", type=uuid.UUID)
@requires_login
def client_delete(client_id: str) -> None:
    """
    Delete the Auth client.
    """
    client = get_client()

    try:
        client.delete_client(client_id)
    except MissingConsent as e:
        raise click.ClickException(
            "Missing consent for the policy API. Please run the following command:\n"
            f"    globus-connect-server session consent {e.scope}"
        )
    click.echo(f"Deleted client {client_id}")
